package com.gic.demo.single.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.authcenter.sdk.GicAuthcenterManager;
import com.gic.authcenter.sdk.exception.NoTokenCacheException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * GIC 认证中心 SDK 测试
 *
 * @author zhurz
 */
@RestController
public class AuthcenterTestController {

    @Autowired
    private GicAuthcenterManager gicAuthcenterManager;

    /**
     * @return 获取认证 url 用于前端访问
     */
    @RequestMapping("/get-authcenter-url")
    public String getAuthcenterUrl() {
        return JSON.toJSONString(gicAuthcenterManager.getAuthorizeUrl());
    }

    /**
     * 接收授权 code
     *
     * @param code 授权 code
     * @return 用户详情
     */
    @RequestMapping("/authcenter-code-callback")
    public String authcenterCodeCallback(String code) {
        return JSON.toJSONString(gicAuthcenterManager.processCode(code));
    }

    /**
     * 获取用户详情
     *
     * @param id 用户 id
     * @return 用户详情
     */
    @RequestMapping("/get-user-details")
    public String getUserDetails(Integer id) {
        try {
            return JSON.toJSONString(gicAuthcenterManager.getUserDetails(id));
        } catch (NoTokenCacheException e) {
            return "无 token 缓存";
        }
    }

}
